mean_saving — skchange

Skip to main content
`Ctrl`+`K`

# mean_saving

mean_saving(precomputed_params: tuple[ndarray, ndarray], starts: ndarray, ends: ndarray) → ndarray

  Calculate the Gaussian mean likelihood saving for each segment.

  The mean_saving calculates the Gaussian likelihood ratio test statistic of the segment starting at start and ending at end having the maximum likelihod estimate of the mean versus zero mean.

  Parameters:
    precomputed_paramstuple[np.ndarray, np.ndarray]

      Precomputed parameters from init_mean_saving.

    startsnp.ndarray

      Start indices of the segments.

    endsnp.ndarray

      End indices of the segments.

  Returns:
    savingsnp.ndarray

      2D array of savings for each segment (rows) and component (columns).